@@ -278,15 +278,20 @@ class ValueTests(TestCase):
             self.assertRaises(ValueError, value.setup, 'TEST')
 
     def test_cache_url_value(self):
+        cache_setting = {
+            'default': {
+                'BACKEND': 'redis_cache.cache.RedisCache',
+                'KEY_PREFIX': '',
+                'LOCATION': 'user@host:port:1'
+            }
+        }
+        cache_url = 'redis://user@host:port/1'
+        value = CacheURLValue(cache_url)
+        self.assertEqual(value.default, cache_setting)
         value = CacheURLValue()
         self.assertEqual(value.default, {})
         with env(CACHE_URL='redis://user@host:port/1'):
-            self.assertEqual(value.setup('CACHE_URL'), {
-                'default': {
-                    'BACKEND': 'redis_cache.cache.RedisCache',
-                    'KEY_PREFIX': '',
-                    'LOCATION': 'user@host:port:1'
-                }})
+            self.assertEqual(value.setup('CACHE_URL'), cache_setting)
         with env(CACHE_URL='wrong://user@host:port/1'):
             self.assertRaises(KeyError, value.setup, 'TEST')
 
